#
# spec file for package pcsc-cyberjack
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %suse_version >= 1120
%if %( pkg-config --modversion udev ) > 190
%define _udevrulesdir /usr/lib/udev/rules.d
%else
%define _udevrulesdir /lib/udev/rules.d
%endif
%endif

Name:           pcsc-cyberjack
Version:        3.99.5final.SP16
Release:        1.2
URL:            https://www.reiner-sct.com/support/support-anfrage/?productGroup=77304735&product=77304820&q=driver&os=Linux#choice5
Summary:        PC/SC IFD Handler for the Reiner SCT Cyberjack USB-SmartCard Readers
License:        LGPL-2.1-or-later
Group:          Productivity/Security
Source:         https://support.reiner-sct.de/downloads/LINUX/V3.99.5_SP16/%{name}-%{version}.tar.bz2
Source1:        %{name}-README.SUSE
Source2:        40-cyberjack.rules
Patch1:         ctapi-cyberjack-configure.patch
Patch2:         no-checksuite.patch
Patch3:         no-libdialog.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define ifddir %(pkg-config --variable=usbdropdir libpcsclite)
BuildRequires:  distribution-release
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkg-config
BuildRequires:  readline-devel
%if %suse_version >= 1120
BuildRequires:  libusb-1_0-devel
BuildRequires:  pkgconfig(udev)
%else
BuildRequires:  hal-devel
BuildRequires:  libusb-devel
%endif
Supplements:    modalias(usb:v0C4Bp0300d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0400d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0401d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0412d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0485d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0500d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0501d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0502d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0503d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0504d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0505d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0506d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0507d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0525d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0527d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0535d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0551d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp0580d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp2000d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp2002d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v0C4Bp2007d*dc*dsc*dp*ic*isc*ip*)
Requires:       pcsc-lite

%description
This package includes the PC/SC IFD handler for the Reiner SCT
Cyberjack pinpad/e-com/RFID USB chipcard readers.

This driver is meant to be used with the PCSC-Lite daemon from the
pcsc-lite package.

%prep
%setup -q
cp -a %{S:1} README.SUSE
%patch -P 1
%patch -P 2 -p1
%patch -P 3 -p1

# unused at the moment; avoid adding GPL as a license
rm -rf libcyberjack checksuite
mkdir -p libcyberjack
cat <<EOF > libcyberjack/Makefile.in
all:
install:
EOF

%build
ACLOCAL="aclocal -I m4" autoreconf -f -i
%configure\
	--disable-static\
	--enable-release\
	--with-usbdropdir=%{ifddir}
make %{?_smp_mflags}

%install
%makeinstall
mkdir -p %{buildroot}/%{_udevrulesdir}
install %{SOURCE2} %{buildroot}/%{_udevrulesdir}
# clean up
mv %{buildroot}/%{_sysconfdir}/cyberjack.conf{.default,}
# exclude
rm -rf %{buildroot}/%{_sysconfdir}/hal/fdi/policy/10osvendor/80-cyberjack.fdi
rm -rf %{buildroot}/%{_libdir}/cyberjack/pcscd_init.diff
chmod a-x %{buildroot}%{_udevrulesdir}/*

%files
%defattr(-,root,root)
%doc COPYRIGHT.LGPL doc/README.* README.SUSE doc/LIESMICH.*
%dir %{ifddir}
%{ifddir}/libifd-cyberjack.bundle
%config(noreplace) %{_sysconfdir}/cyberjack.conf
%{_udevrulesdir}/*

%changelog
* Tue Aug 27 2024 Dominik Heidler <dheidler@suse.de>
- update to 3.99.5 Service Pack 16
  * add REINER SCT cyberJack RFID standard EN
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Jun 21 2022 chris@computersalat.de
- update to 3.99.5 Service Pack 15
  * add REINER SCT cyberJack wave HUN
  * add REINER SCT cyberJack RFID komfort FON
- update supplements device list
* Wed Jan 27 2021 Wolfgang Rosenauer <wr@rosenauer.org>
- removed obsolete pcsc-cyberjack-3.99.5final.SP09-gcc10.patch
* Thu Jan  7 2021 Matthias Mailänder <mailaender@opensuse.org>
- update to 3.99.5 Service Pack 14
- use https://en.opensuse.org/SourceUrls
- remove check for obsolete SUSE versions
* Wed Dec  2 2020 Marcus Rueckert <mrueckert@suse.de>
- make sure that the rule files are not marked as executable
* Sun Jun  7 2020 Jason Sikes <jsikes@suse.com>
- Add patch to enable compile with gcc10
  * pcsc-cyberjack-3.99.5final.SP09-gcc10.patch
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through -mini flavors.
* Thu May  2 2019 Jan Engelhardt <jengelh@inai.de>
- Remove redundant %%clean section, replace old $RPM_* shell vars.
* Thu May  2 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- removed unused code which was still built
  (no-checksuite.patch, no-libdialog.patch, and manual removal from
  source archive)
- removed obsolete patch
  ctapi-cyberjack-check.patch
* Sat Jan 19 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- update to 3.99.5 Service Pack 13
  * Update to the Reiner-SCT repository rev cyberJack@1374
- removed obsolete patches
  * a58a29c08b1da647e5efe08641abcb0144740b8b.patch
  * pcsc-cyberjack-fprintf.patch
- add new devices to udev rules (2000, 0551, 2002)
* Sat Jul 14 2018 thb@documentfoundation.org
- Add patch to get cyberJack RFID komfort working
  (a58a29c08b1da647e5efe08641abcb0144740b8b.patch)
  https://forum.reiner-sct.com/index.php?/topic/3728-failed_to_transmit_control_command_to_the_terminal
* Sat Jul 14 2018 wr@rosenauer.org
- update to 3.99.5 Service Pack 12
  * Add support for cyberJack one MF
  * man-page removed upstream
* Sun Oct 15 2017 wr@rosenauer.org
- update to 3.99.5 Service Pack 11
  * add support for cyberJack one
  * validated that crash on exit is fixed (boo#908092)
* Sun Feb 26 2017 wr@rosenauer.org
- update to 3.99.5 Service Pack 10
  * Add support for SHUReader and SISReader
  * Update to the Reiner-SCT repository rev cyberJack@1305
* Wed Mar 16 2016 wr@rosenauer.org
- update to 3.99.5 Service Pack 09
  * Fix USB unplug problems
  * removed cyberjack diag tool
* Mon Sep 21 2015 wr@rosenauer.org
- update to 3.99.5 Service Pack 08
  * update COPYRIGHT.GPL, COPYRIGHT.LGPL and FSF address
  * Add support for cyberJack secoder TLS, CSYOReader and CBDRReader
  * Update to the Reiner-SCT repository rev cyberJack@1292
  * Add support for CyberJack cv and SoliSYSTEMS
- removed obsolete data-structure.patch
* Sun May  4 2014 wr@rosenauer.org
- fix for changed data structure in PCSC's reader.h
  (data-structure.patch)
* Tue Apr 29 2014 wr@rosenauer.org
- fixed typo in udev rule (bnc#881517)
* Tue Apr 22 2014 wr@rosenauer.org
- Updated to version 3.99.5 Service Pack 05
  * Add support for CyberJack Go
  * Add support for CyberJack wav
- removed obsolete pcsc-cyberjack-gcc47.patch
* Mon Oct 29 2012 wr@rosenauer.org
- fixed typo in logmessage (pcsc-cyberjack-fprintf.patch)
* Thu Oct 18 2012 fcrozat@suse.com
- Fix build with new udev rules directory location.
* Wed Mar 21 2012 dimstar@opensuse.org
- Add pcsc-cyberjack-gcc47.patch: Fix build with gcc 4.7.
* Sun Dec 25 2011 wr@rosenauer.org
- Updated to version 3.99.5 Service Pack 03
  * fix FEATURE_MCT_READERDIRECT reader disconnect on pinpad
  * add support for cyberJack compact
  * fix speed problem pinpad <--> seccos6 card
* Wed Nov 16 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Jun 25 2011 wr@rosenauer.org
- Updated to version 3.99.5 Service Pack 02
  * PinVerify/Modify-Problem Responsecode 0x6b80 fixed
* Wed Jun 22 2011 wr@rosenauer.org
- add patch for compatibility with pcsc-lite >= 1.7.3
* Thu Jun  9 2011 wr@rosenauer.org
- Updated to version 3.99.5 Service Pack 01
  * fixed some timing issues with certain cards
  * fixed change/modify pin/tan for the pinpad
* Tue May 17 2011 wr@rosenauer.org
- Updated to version 3.99.5final released by Reiner-SCT
  (during 3.99.x phase there were two different code lines and
  therefore the version numbers do not match; this version is the
  official released version from the vendor)
* Sun May 15 2011 wr@rosenauer.org
- Updated to version 3.99.10beta
  * ctapi interface removed -> removed ctapi-cyberjack subpackage
- dropped spec file support for 10.1 and older
* Tue Apr  5 2011 wr@rosenauer.org
- Updated to version 3.3.6
  * no upstream changelog available
- added man pages
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Sat Mar 19 2011 wr@rosenauer.org
- add device id 500 (cyberjack rfid) to udev rules
* Tue Sep  7 2010 aj@suse.de
- Remove unneeded dependency on sysfsutils.
* Tue Apr  6 2010 wr@rosenauer.org
- Updated to version 3.3.5
  * fixed issues with 0x300 and 0x401 devices
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Jan  6 2010 sbrabec@suse.cz
- Use libusb1 in >= 11.2.
- Added back support for SLES10.
* Mon Dec 21 2009 wr@rosenauer.org
- Updated to version 3.3.3
  * compatible with recent libusb
- Added udev rules for ACL access (bnc#555660)
- Removed support for 10.3 and older
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 3.3.2:
  * sanity checks
  * inprovement of debugging features
* Wed Jun 17 2009 sbrabec@suse.cz
- Fixed compilation failure in Factory.
* Thu Apr  9 2009 sbrabec@suse.cz
- Added README.SUSE (bnc#438131#c33).
* Tue Apr  7 2009 sbrabec@suse.cz
- Updated to version 3.3.1:
  * improves support for rdesktop
  * fixes some PC/SC-related bugs
  * implements FEATURE_MCT_READER_DIRECT
  * support for latest versions of pcsc-lite which rely on libhal
- pcsc-cyberjack requires pcsc-lite.
* Fri Apr  3 2009 sbrabec@suse.cz
- Use modalias supplements instead of eID issuer locales.
- Fixed buffer underflow.
* Fri Mar 20 2009 crrodriguez@suse.de
- fix build with GCC 4.4
- fix Requires
- fix buildrequires
* Mon Feb  2 2009 wr@opensuse.org
- Fixed library path again
- Removed double doc (licenses)
- Require "licenses" package explicitely where needed
- Added %%{_libdir}/cyberjack/getdist.sh to make the cyberjack
  support script more useful
- Install ctapi libs to %%{_libdir} (for upstream compat) and for
  backwards compat link them to %%{_libdir}/readers
- Patched some support script's messages to fit openSUSE's package
  (ctapi-cyberjack-check.patch)
* Wed Jan 21 2009 sbrabec@suse.cz
- Renamed capabilities name, create category FDI key. (bnc#438131)
* Tue Jan 13 2009 wr@opensuse.org
- Adopt new HAL acl handling. (bnc#438131)
* Tue Jan  6 2009 sbrabec@suse.cz
- Signed-off.
* Sun Dec  7 2008 wr@opensuse.org
- requiring dummy-release only works from 11.1 on
* Fri Sep 19 2008 ro@suse.de
- replacing openSUSE-release with dummy-release in buildreq
- patch configure, parsing /etc/SuSE-release is a really bad idea
* Mon Sep  8 2008 sbrabec@suse.cz
- Update to version 3.3.0:
  * improves support for rdesktop
  * fixes some PC/SC-related bugs
  * implements FEATURE_MCT_READER_DIRECT
  * support for latest versions of pcsclite which rely on libHAL
* Wed Jul 30 2008 wr@opensuse.org
- Update to version 3.3.0beta4:
  * IFD handler works correctly again (#413282)
- Fixed hal rules for openSUSE 11.0
* Thu May  8 2008 schwab@suse.de
- Fix configure script.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Apr  4 2008 sbrabec@suse.cz
- Updated to version 3.1.0:
  * introduces a new method of selecting devices by serial number.
  * adds support for Cyberjacks connected via serial cable.
  * fixes a problem with the APDU 20,10 and Ecom(a).
  * special handling for port values 0x9000 and above.
  * with the latest firmware should fix the problems Cyberjack Ecom
    (a).
  * Bug fixes.
* Tue Dec  4 2007 sbrabec@suse.cz
- Updated to version 3.0.5:
  * fixes a bug which makes Moneyplex unable to read cards with new
    ecoms
  * enables reading of German medical cards with 0x400 devices
  * introduces a workaround for hanging USB hardware
  * fixes a bug in the USB logging code
  * fixes bug which can cause the driver to crash
- Fixed hal rules for OpenSUSE >= 10.3 (#336704).
- Added symlinks to work-around incorrect dynamic linking
  (#336707).
* Tue Jul 31 2007 sbrabec@suse.cz
- Detect SuSE distribution correctly.
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated package from Build Service security:chipcard.
* Mon Jul 23 2007 wr@rosenauer.org
- update to version 3.0.3
- added 10.2 to configure options
- removed rpath patch since it doesn't work anymore
* Wed May 16 2007 olh@suse.de
- Remove unneded Requires libusb
* Tue Apr 17 2007 sbrabec@suse.cz
- Updated package from Build Service security:chipcard (#264252).
- Spec file cleanup.
* Tue Apr 10 2007 wr@rosenauer.org
- update to version 2.0.14
  * ctapi.h is not packaged anymore (someone need it?)
* Mon Jan  8 2007 wr@rosenauer.org
- update to version 2.0.13
* Wed Dec 27 2006 wr@rosenauer.org
- update to version 2.0.13beta5
* Wed Dec 20 2006 wr@rosenauer.org
- update to version 2.0.13beta3
* Mon Aug  7 2006 stark@suse.de
- added HAL config to map the reader to usb resmgr class (#191958)
* Sat May  6 2006 kukuk@suse.de
- Fix inclusion of kernel headers
* Sat Apr  1 2006 sndirsch@suse.de
- added missing locale provides (Bug #161867)
* Mon Mar 27 2006 schwab@suse.de
- Fix building of shared libs.
* Tue Mar  7 2006 agruen@suse.de
- Add modalias tags (155357).
* Thu Mar  2 2006 stark@suse.de
- update to version 2.0.10
  * version 2.0.9 almost crashed everytime accessing the reader
  * added wrapper/Extension code to libusb-0.1 to support
    asynchronous requests
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 stark@suse.de
- fixed file modes of executables
* Wed Jan  4 2006 stark@suse.de
- readded rpath and make options patches
* Tue Jan  3 2006 mjancar@suse.cz
- move to separate source package
* Mon Jan  2 2006 stark@suse.de
- removed obsolete hotplug stuff for cyberjack
- Updated pcsc-lite to version 1.2.9-beta9
- Updated CCID driver to 0.9.4
- Updated GemPC driver to 1.0.0
- package pkgconfig files to be able to build drivers outside
  the package
* Tue Dec 20 2005 ro@suse.de
- removed unpackaged man-page symlinks
* Tue Nov 29 2005 ro@suse.de
- remove keeper from nfb (unused)
* Mon Oct 10 2005 stark@suse.de
- Updated towitoko driver to 2.0.7 and install USB bundle
* Wed Sep 21 2005 stark@suse.de
- Repackaged CCID as bundle for USB usage (#116497)
* Tue Sep 20 2005 stark@suse.de
- handle old reader.conf in upgrade case
- compile with -fno-strict-aliasing
- fixed missing return in ctapi-cyberjack
* Sat Sep 17 2005 stark@suse.de
- Updated pcsc-lite to version 1.2.9beta8 (#116497)
  * use /etc/reader.conf.d/
  * adapted init script to create /etc/reader.conf
- Updated cyberjack driver to version 2.0.9
  * use rpath for cyberjack tools
- Updated ccid driver to version 0.9.3 (#116497)
- Use RPM_OPT_FLAGS everywhere
- Fixed serious compiler warnings
* Mon Sep  5 2005 skh@suse.de
- fix off-by-one error in hotplug_libusb.c [#112964]
* Mon Aug 29 2005 skh@suse.de
- Remove unnecessary files from pcsc-acr38 again [#112927]
* Mon Aug 29 2005 skh@suse.de
- package ACR38 driver in correct bundle format [#112927]
- remove orphaned /var/run/pcscd.pub when necessary [#112928]
- update ACR38u driver to version 100705 to fix crash when reader
  is plugged in [#112964]
* Tue Aug 16 2005 skh@suse.de
- Updated ACR38u driver to version 100703
* Tue Jul 26 2005 okir@suse.de
- Added ACR38u driver
* Tue Jul 26 2005 okir@suse.de
- Updated description in init script (#79287)
* Thu Jun 16 2005 meissner@suse.de
- use RPM_OPT_FLAGS in 1 more driver
- added includes to avoid implict declaration of memcpy and similar.
* Mon Apr 18 2005 ro@suse.de
- make it build with gcc-4
* Thu Mar 17 2005 okir@suse.de
- Disable support for extended-apdus, it eats 32MB of memory (#73629)
* Thu Mar 10 2005 okir@suse.de
- Fix default search location for USB bundles
* Fri Jan 21 2005 okir@suse.de
- Updated to latest upstream version
- Updated several drivers
- Added CCID driver
- Provide a more informative readers.conf file (#42620)
* Thu Jan 20 2005 ro@suse.de
- drop subpackage gpr400
* Wed Apr 28 2004 ro@suse.de
- compile formaticc with no-strict-aliasing
- fix unused return type in musclecard.c
* Wed Mar 31 2004 okir@suse.de
- Properly install testpcsc, formaticc (#37625)
- Build towitoko driver with --enable-win32-com
* Thu Mar 18 2004 okir@suse.de
- cyberjack apps installed in /bin should be executable (#36409)
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Aug  5 2003 mge@suse.de
- merge ctapi-cyberjack into pcsc-lite: two additional
  packages are created: ctapi-cyberjack and pcsc-cyberjack
* Wed Jun 25 2003 ro@suse.de
- remove unpackaged files from buildroot
- added directories to filelist
* Fri Nov 29 2002 okir@suse.de
- added -fPIC when building eToken driver
* Fri Nov 29 2002 okir@suse.de
- Updated to latest upstream version
- Included driver for Aladdin eToken PRO
- More GNU auto#*@! headaches
- Various minor fixes
* Wed Aug 28 2002 okir@suse.de
- Moved shared objects to /usr/lib64 on ppc64/s390x (#18421)
* Mon Aug  5 2002 olh@suse.de
- fix initscript, Should-start: setserial hotplug
* Fri Aug  2 2002 okir@suse.de
- added PreReq for insserv_and_fillup
* Wed Jul 31 2002 okir@suse.de
- fixed build problem on s390x (force aclocal.m4 regen)
* Tue Jun 25 2002 ro@suse.de
- use -fPIC when building a shared lib
* Wed Jun 12 2002 okir@suse.de
- fix for bug #15051 (hey, it's a palindrome bug:):
  missing %%doc DRIVERS file; misc silly binaries moved
  out of /usr/bin
* Tue Apr 30 2002 okir@suse.de
- Fixed build problem introduced by previous patch
* Tue Apr 30 2002 okir@suse.de
- updated to latest upstream version
- added drivers for these readers: Towitoko, Schlumberger Reflex 6x,
  Gemplus GPR 400, GemPlus GemPC 410/430
* Mon Apr  8 2002 ro@suse.de
- fixed for latest automake/autoconf
* Wed Feb 13 2002 stark@suse.de
- spec-file cleanup
- LSB compliant init-script
* Mon Jan 14 2002 ro@suse.de
- removed START_PCSCD
* Wed Nov 14 2001 ro@suse.de
- call aclocal
* Sun Aug 26 2001 mge@suse.de
- updated to 1.0.0Beta
- fixed /etc/init.d/pcscd status-handling (bug #9069)
* Thu Jun  7 2001 ro@suse.de
- fix broken Makefile.am
* Sun Apr 22 2001 mge@suse.de
- update to 0.9.1
* Wed Apr 18 2001 mge@suse.de
- created package
